@@ -147,6 +147,7 @@ class AutoTrader():
         self.data_end   = None
         self.data_file  = None
         self.MTF_data_files = None
+        self.local_data = None
         self.backtest_initial_balance = None
         self.backtest_spread = None
         self.backtest_commission = None
@@ -167,7 +168,14 @@ class AutoTrader():
         self.scan_results = {}
         
         # Plotting
-        self._custom_ap_settings = False
+        self.max_indis_over = 3
+        self.max_indis_below = 2
+        self.fig_tools = "pan,wheel_zoom,box_zoom,undo,redo,reset,save,crosshair"
+        self.ohlc_height = 400
+        self.ohlc_width = 800
+        self.top_fig_height = 150
+        self.bottom_fig_height = 150
+        self.jupyter_notebook = False
         
     def run(self):
         '''
@@ -292,8 +300,9 @@ class AutoTrader():
         ''' -------------------------------------------------------------- '''
         for strategy in self.strategies:
             for instrument in self.strategies[strategy]['WATCHLIST']:
+                data_dict = self.local_data[instrument] if self.local_data is not None else None
                 bot = AutoTraderBot(instrument, self.strategies[strategy],
-                                        self.broker, self)
+                                    self.broker, data_dict, self)
                 
                 if self.detach_bot is True and self.backtest_mode is False:
                     # Send bot to bot manager to monitor stream
@@ -377,7 +386,7 @@ class AutoTrader():
                                  left_index=True, right_index=True).Profit.cumsum()
                         cpl_dict[bot.instrument] = profit_df
                     
-                    ap = autoplot.AutoPlot(bot.data)
+                    ap = self._instantiate_autoplot(bot.data)
                     ap._plot_multibot_backtest(self.multibot_backtest_results, 
                                                NAV, cpl_dict, margin)
         
@@ -406,12 +415,9 @@ class AutoTrader():
     def plot_settings(self, max_indis_over=3, max_indis_below=2,
                       fig_tools="pan,wheel_zoom,box_zoom,undo,redo,reset,save,crosshair",
                       ohlc_height=400, ohlc_width=800, top_fig_height=150,
-                      bottom_fig_height=150):
+                      bottom_fig_height=150, jupyter_notebook=False):
         ''' Configures settings for AutoPlot. '''
         
-        # Set flag for custom settings
-        self._custom_ap_settings = True
-        
         # Assign attributes
         self.max_indis_over     = max_indis_over
         self.max_indis_below    = max_indis_below
@@ -420,6 +426,7 @@ class AutoTrader():
         self.ohlc_width         = ohlc_width
         self.top_fig_height     = top_fig_height
         self.bottom_fig_height  = bottom_fig_height
+        self.jupyter_notebook   = jupyter_notebook
     
     def _instantiate_autoplot(self, data):
         ''' Creates instance of AutoPlot. '''
@@ -427,15 +434,15 @@ class AutoTrader():
         # Create nominal instance
         ap = autoplot.AutoPlot(data)
         
-        if self._custom_ap_settings:
-            # Assign attributes
-            ap.max_indis_over     = self.max_indis_over
-            ap.max_indis_below    = self.max_indis_below
-            ap.fig_tools          = self.fig_tools
-            ap.ohlc_height        = self.ohlc_height
-            ap.ohlc_width         = self.ohlc_width
-            ap.top_fig_height     = self.top_fig_height
-            ap.bottom_fig_height  = self.bottom_fig_height
+        # Assign attributes
+        ap.max_indis_over     = self.max_indis_over
+        ap.max_indis_below    = self.max_indis_below
+        ap.fig_tools          = self.fig_tools
+        ap.ohlc_height        = self.ohlc_height
+        ap.ohlc_width         = self.ohlc_width
+        ap.top_fig_height     = self.top_fig_height
+        ap.bottom_fig_height  = self.bottom_fig_height
+        ap.jupyter_notebook   = self.jupyter_notebook
         
         return ap
     
@@ -530,7 +537,7 @@ class AutoTrader():
                   use_stream=False, detach_bot=False,
                   check_data_alignment=True, allow_dancing_bears=False,
                   account_id=None, environment='demo', show_plot=False,
-                  MTF_initialisation=False):
+                  MTF_initialisation=False, jupyter_notebook=False):
         '''
         AutoTrader Run Configuration
         -------------------------------
@@ -579,6 +586,59 @@ class AutoTrader():
         self.environment = environment
         self.show_plot = show_plot
         self.MTF_initialisation = MTF_initialisation
+        self.jupyter_notebook = jupyter_notebook
+        
+    def add_data(self, data_dict, data_directory='price_data', abs_dir_path=None):
+        ''' 
+        Add local data to run backtest on. Note that to ensure proper directory 
+        configuration, this method should only be called after calling 
+        autotrader.configure().
+        
+        Parameters:
+            data_dict (dict): a dictionary containing the filenames of the datasets
+                 to be used. For example:
+                    data_dict = {'product1': 'filename1.csv',
+                                 'product2': 'filename2.csv'}
+                 
+                 In the case of MTF data, the data_dict will look as follows:
+                     data_dict = {'product1': {'H1': 'product1_H1.csv',
+                                               'D': 'product1_D.csv'},
+                                  'product2': {'H1': 'product2_H1.csv',
+                                               'D': 'product2_D.csv'}
+                                  }
+                 
+                 Note that the filenames in the dict above must be present in the 
+                 data directory, as specified by the data_directory or abs_dir_path
+                 parameters.
+                 
+            data_directory (str): the name of the sub-directory containing price
+                data files. This directory should be located in the project
+                home directory (at.home_dir).
+            
+            abs_dir_path: the absolute path to the data_directory. This parameter
+                may be used when the datafiles are stored outside of the project
+                directory.
+        '''
+        
+        dir_path = abs_dir_path if abs_dir_path is not None else os.path.join(self.home_dir, data_directory)
+        
+        # Assign local data attribute
+        local_data = {}
+        
+        # for loop to populate local_data
+        for product in data_dict:
+            if type(data_dict[product]) == dict:
+                # MTF data
+                MTF_data = {}
+                for timeframe in data_dict[product]:
+                    MTF_data[timeframe] = os.path.join(dir_path, data_dict[product][timeframe])
+                
+                local_data[product] = MTF_data
+            else:
+                # Single timeframe data
+                local_data[product] = os.path.join(dir_path, data_dict[product])
+        
+        self.local_data = local_data
         
     
     def scan(self, strategy_filename=None, strategy_dict=None, scan_index=None):
@@ -625,7 +685,7 @@ class AutoTrader():
             Parameters:
                 bot (class): AutoTrader bot class containing backtest results.
         '''
-        ap = autoplot.AutoPlot(bot.data)
+        ap = self._instantiate_autoplot(bot.data)
         profit_df = pd.merge(bot.data, 
                              bot.backtest_summary['trade_summary']['Profit'], 
                              left_index=True, right_index=True).Profit.cumsum()
